==> Alpha-0.7.4-src.tar.bz2: Alpha-0.7.4-src/Alpha/AboutDlg.cpp <==
// AboutDlg.cpp
// (c) 2003 exeal

#include "StdAfx.h"
#include "resource.h"
#include "AboutDlg.h"
using Alpha::CAboutDlg;


// CAboutDlg class implementation
/////////////////////////////////////////////////////////////////////////////

bool CAboutDlg::OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl) {
	if(wID == IDC_LINK_HOMEPAGE) {
		::ShellExecuteW(0, 0, L"http://www.interq.or.jp/student/exeal/dss/res/alpha/", 0, 0, SW_SHOWNORMAL);
		return true;
	} else if(wID == IDC_LINK_SOURCEFORGE) {
		::ShellExecuteW(0, 0, L"http://sourceforge.jp/projects/alpha/", 0, 0, SW_SHOWNORMAL);
		return true;
	}

	return CDialog::OnCommand(wID, wNotifyCode, hwndCtrl);
}

bool CAboutDlg::OnInitDialog(HWND hwndFocus, LPARAM lInitParam) {
	CDialog::OnInitDialog(hwndFocus, lInitParam);

	m_oHomePage.m_clrBackground = 0x80000000;
	m_oHomePage.Create(m_hWnd, ::GetModuleHandle(0), IDC_LINK_HOMEPAGE);
	m_oHomePage.SetWindowText(L"http://www.interq.or.jp/student/exeal/dss/res/alpha/");
	m_oHomePage.SetWindowPos(0, 81, 104, 0, 0, SWP_NOSIZE | SWP_NOZORDER);
//	m_oHomePage.MoveWindow(81, 104, 276, 14);
	m_oSourceForge.m_clrBackground = 0x80000000;
	m_oSourceForge.Create(m_hWnd, ::GetModuleHandle(0), IDC_LINK_SOURCEFORGE);
	m_oSourceForge.SetWindowText(L"http://sourceforge.jp/projects/alpha/");
	m_oSourceForge.SetWindowPos(0, 81, 120, 0, 0, SWP_NOSIZE | SWP_NOZORDER);
//	m_oSourceForge.MoveWindow(81, 120, 276, 14);

	EnableToolTips(true);
	AddToolTip(m_oHomePage, L"Alpha ̃y[W - Dynamic Scripting");
	AddToolTip(m_oSourceForge, L"Alpha @ SourceForge");

	return true;
}

/* [EOF] */

==> Alpha-0.7.5.4-src.tar.bz2: Alpha-0.7.5.4-src/Alpha/AboutDlg.cpp <==
// AboutDlg.cpp
// (c) 2004 exeal

#include "StdAfx.h"
#include "resource.h"
#include "AboutDlg.h"
using Alpha::CAboutDlg;


// CAboutDlg class implementation
/////////////////////////////////////////////////////////////////////////////

bool CAboutDlg::OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl) {
	if(wID == IDC_LINK_HOMEPAGE) {
		::ShellExecuteW(0, 0, L"http://www.interq.or.jp/student/exeal/dss/res/alpha/", 0, 0, SW_SHOWNORMAL);
		return true;
	} else if(wID == IDC_LINK_SOURCEFORGE) {
		::ShellExecuteW(0, 0, L"http://sourceforge.jp/projects/alpha/", 0, 0, SW_SHOWNORMAL);
		return true;
	}

	return CDialog::OnCommand(wID, wNotifyCode, hwndCtrl);
}

bool CAboutDlg::OnInitDialog(HWND hwndFocus, LPARAM lInitParam) {
	CDialog::OnInitDialog(hwndFocus, lInitParam);

	m_oHomePage.m_clrBackground = 0x80000000;
	m_oHomePage.Create(m_hWnd, ::GetModuleHandle(0), IDC_LINK_HOMEPAGE);
	m_oHomePage.SetWindowText(L"http://www.interq.or.jp/student/exeal/dss/res/alpha/");
	m_oHomePage.SetWindowPos(0, 88, 98, 0, 0, SWP_NOACTIVATE | SWP_NOSIZE | SWP_NOZORDER);
//	m_oHomePage.MoveWindow(81, 104, 276, 14);
	m_oSourceForge.m_clrBackground = 0x80000000;
	m_oSourceForge.Create(m_hWnd, ::GetModuleHandle(0), IDC_LINK_SOURCEFORGE);
	m_oSourceForge.SetWindowText(L"http://sourceforge.jp/projects/alpha/");
	m_oSourceForge.SetWindowPos(0, 88, 114, 0, 0, SWP_NOACTIVATE | SWP_NOSIZE | SWP_NOZORDER);
//	m_oSourceForge.MoveWindow(81, 120, 276, 14);

	EnableToolTips(true);
	AddToolTip(m_oHomePage, L"Alpha @ Dynamic Scripting");
	AddToolTip(m_oSourceForge, L"Alpha @ SourceForge");

	return true;
}

/* [EOF] */
